SentenceIndex class

Constructors

SentenceIndex({required int start, required int end})

Properties

end ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ int
getter/setter pair

Methods

getEnd() → int
getStart() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEnd(int end) → void
setStart(int start) → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited