Stats class

Constructors

Stats()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

COMMON ↔ int
getter/setter pair
DA ↔ int
getter/setter pair
DEFAULT ↔ int
getter/setter pair
HAM ↔ int
getter/setter pair
JYO ↔ int
getter/setter pair
SB ↔ int
getter/setter pair
UM ↔ int
getter/setter pair
YO ↔ int
getter/setter pair

Static Methods

getValue() → int