Backend class

Constructors

Backend()

Properties

endPoint ↔ List<String>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
needToReplaceZwsp ↔ List<String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

findAll(String aStr, String sub) → List<int>
getChunkWithIndex(List<SentenceIndex> span, String text) → ChunkWithIndex
lindexSplit(String text, List<int> indices) → List<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postProcessing(List<String> results, List<String> postProcessingList) → List<String>
realignByQuote(String text, int lastQuotePos, String quoteType, bool useHeuristic, bool useQuotesBracketsProcessing, int maxRecoverStep, int maxRecoverLength, int recoverStep) → List<String>
splitChunks(String text, int maxLength, bool overlap, bool useHeuristic, bool useQuotesBracketsProcessing, int maxRecoverStep, int maxRecoverLength) → List<ChunkWithIndex>
splitSentences(String text, bool useHeuristic, bool useQuotesBracketsProcessing, int maxRecoverStep, int maxRecoverLength, int recoverStep, bool useStrip) → List<String>
splitSentencesIndex(String text, bool useHeuristic, bool useQuotesBracketsProcessing, int maxRecoverStep, int maxRecoverLength) → List<SentenceIndex>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited